From: Jakub Jirutka <jakub@jirutka.cz>
Date: Sat, 20 Aug 2022 00:09:00 +0200
Subject: [PATCH] Build with native zlib-ng (no compat)

Use zlib-ng (libz-ng-sys) with native API (no compat mode) that can
co-exist with system libz (loaded by e.g. libcurl).

--- a/git-features/Cargo.toml
+++ b/git-features/Cargo.toml
@@ -46,2 +46,4 @@
 zlib-rust-backend = ["flate2/rust_backend"]
+## Use zlib-ng (libz-ng-sys) with native API (no compat mode) that can co-exist with system libz.
+zlib-ng = ["flate2/zlib-ng"]
 
--- a/git-repository/Cargo.toml
+++ b/git-repository/Cargo.toml
@@ -66,3 +66,2 @@
                     "git-features/parallel",
-                    "git-features/zlib-ng-compat",
                     "git-pack/pack-cache-lru-static",
--- a/Cargo.toml
+++ b/Cargo.toml
@@ -33 +33 @@
-fast = ["git-features/parallel", "git-features/fast-sha1", "git-features/zlib-ng-compat", "git-repository/max-performance"]
+fast = ["git-features/parallel", "git-features/fast-sha1", "git-features/zlib-ng", "git-repository/max-performance"]
--- a/Cargo.lock
+++ b/Cargo.lock
@@ -911,6 +911,7 @@
 checksum = "f82b0f4c27ad9f8bfd1f3208d882da2b09c301bc1c828fd3a00d0216d2fbbff6"
 dependencies = [
  "crc32fast",
+ "libz-ng-sys",
  "libz-sys",
  "miniz_oxide",
 ]
@@ -2005,6 +2006,16 @@
  "openssl-sys",
  "pkg-config",
  "vcpkg",
+]
+
+[[package]]
+name = "libz-ng-sys"
+version = "1.1.8"
+source = "registry+https://github.com/rust-lang/crates.io-index"
+checksum = "4399ae96a9966bf581e726de86969f803a81b7ce795fcd5480e640589457e0f2"
+dependencies = [
+ "cmake",
+ "libc",
 ]
 
 [[package]]
